BoardingPolicy

Trait BoardingPolicy 

pub trait BoardingPolicy {
    // Required method
    fn may_board(
        &self,
        waiter: &Waiter,
        vehicle: &TransitVehicle,
        served_stops: &[u64],
    ) -> bool;

    // Provided method
    fn max_boardings(&self) -> Option<u32> { ... }
}
Policy for deciding which queued passengers board a vehicle.

Required Methods

fn may_board( &self, waiter: &Waiter, vehicle: &TransitVehicle, served_stops: &[u64], ) -> bool

Return true if a waiter may board this vehicle.

Provided Methods

fn max_boardings(&self) -> Option<u32>

Maximum number of passengers this boarding event may board.

Implementors