pub struct DispatchContext<'a> {
pub route: &'a Route,
pub now_s: f64,
pub active_vehicles: usize,
pub max_active_vehicles: Option<usize>,
}Expand description
Dispatch request context for one route at one simulation time.
Fields
route: &'a RouteRoute being considered for dispatch.
now_s: f64Current simulation time in seconds.
active_vehicles: usizeNumber of currently active vehicles assigned to this route.
max_active_vehicles: Option<usize>Optional active-vehicle cap for this route.
Implementations
Sourceimpl<'a> DispatchContext<'a>
impl<'a> DispatchContext<'a>
Sourcepub fn new(route: &'a Route, now_s: f64) -> DispatchContext<'a>
pub fn new(route: &'a Route, now_s: f64) -> DispatchContext<'a>
Create a dispatch context for route at now_s.
Sourcepub fn with_active_vehicles(
self,
active_vehicles: usize,
max_active_vehicles: Option<usize>,
) -> DispatchContext<'a>
pub fn with_active_vehicles( self, active_vehicles: usize, max_active_vehicles: Option<usize>, ) -> DispatchContext<'a>
Attach active-vehicle counts and an optional cap.