pub trait BoardingPolicy {
// Required method
fn may_board(
&self,
waiter: &Waiter,
vehicle: &TransitVehicle,
served_stops: &[u64],
) -> bool;
// Provided method
fn max_boardings(&self) -> Option<u32> { ... }
}Expand description
Policy for deciding which queued passengers board a vehicle.
Required Methods
Provided Methods
Sourcefn max_boardings(&self) -> Option<u32>
fn max_boardings(&self) -> Option<u32>
Maximum number of passengers this boarding event may board.